# Apptio Technical Overview
### On this page
  * [Configure the Integration in SAP LeanIX](https://help.sap.com/docs/leanix/ea/apptio-technical-overview#configure-the-integration-in-sap-leanix)
  * [Apptio Endpoints](https://help.sap.com/docs/leanix/ea/apptio-technical-overview#apptio-endpoints)
  * [View the Integration Status](https://help.sap.com/docs/leanix/ea/apptio-technical-overview#view-the-integration-status)


Configure the Apptio integration in SAP LeanIX.
